@@ -50,6 +50,20 @@ class VariableClEnvPath(Variable):
     type = 'list'
     value = list(zip(*_envData)[1])
 
+class VariableClTemplateData(TableVariable):
+    """
+    Aliases to templates path
+    """
+    source = ["cl_template_location","cl_template_path"]
+
+class VariableClTemplateLocation(Variable):
+    """
+    Name to templates
+    """
+    type = 'list'
+    value = ["overlay","local","remote"]
+
+
 class VariableClTemplatePath(Variable):
     """
     Path to information file on server
